'use strict';

const webpack = require('webpack');
const fs = require('fs');
const mime = require("mime");
const path = require("path");
const mkdirp = require('mkdirp');

module.exports = {
    "ui": {
        "port": 3001,
        "weinre": {
            "port": 8080
        }
    },
    files: [
      "dist/**",
      "test/**"
    ],
    "watchOptions": {},
    "server": {
      baseDir: [
        "dist",
        "test",
      ],
      routes: {
        "/~/npm": "node_modules",
        "/~/test": "test",
      },
      directory: true,
      index: "uat-index.htm"
    },
    startPath: "/uat-index.html",
    "proxy": false,
    "port": 3000,
    "middleware": [function(req, res, next) {
      if(/^\/\~\/test\//.test(req.url) === false) {
        return next();
      }
      const url = req.url.replace('/~', '');
      console.log('bs: url ', url);
      if(!fs.lstatSync(__dirname + url).isFile()) {
        console.log('bs: filename not a file ', url);
        return next('error while getting file');
      }
      const curPath = __dirname + url;
      const tempPath = __dirname + url.replace(/^\/test\//, '/test/.temp/');
      mkdirp.sync(__dirname + '/test/.temp/uat-assets/');

      const webpackConfig = require('./test/webpack-uat.config');
      webpackConfig.entry = [curPath];
      webpackConfig.output.filename = tempPath;
      webpack(webpackConfig, function(error, stats) {
        const status = stats.toString({});
        console.error(status);
        console.error(status.indexOf('failed') >= 0);
        let content = '';
        if(status.indexOf('failed') >= 0) {
          console.log(status.indexOf('failed'));
          throw new Error(status);
        } else {
          content = fs.readFileSync(tempPath, 'utf8');
        }
        res.setHeader("Access-Control-Allow-Origin", "*"); // To support XHR, etc.
  			res.setHeader("Content-Type", mime.lookup(path.basename(tempPath)));
  			res.setHeader("Content-Length", content.length);

        const headers = {};
				for(var name in headers) {
					res.setHeader(name, headers[name]);
				}
        if (res.send) {
          res.send(content);
        } else if (res.end) {
          res.end(content);
        }
      });

    }],
    "serveStatic": [],
    "ghostMode": {
        "clicks": true,
        "scroll": true,
        "forms": {
            "submit": true,
            "inputs": true,
            "toggles": true
        }
    },
    "logLevel": "info",
    "logPrefix": "BS",
    "logConnections": false,
    "logFileChanges": true,
    "logSnippet": true,
    "rewriteRules": false,
    "open": "local",
    "browser": "default",
    "xip": false,
    "hostnameSuffix": false,
    "reloadOnRestart": false,
    "notify": true,
    "scrollProportionally": true,
    "scrollThrottle": 0,
    "scrollRestoreTechnique": "window.name",
    "scrollElements": [],
    "scrollElementMapping": [],
    "reloadDelay": 0,
    "reloadDebounce": 0,
    "reloadThrottle": 0,
    "plugins": [],
    "injectChanges": true,
    "minify": true,
    "host": null,
    "localOnly": false,
    "codeSync": true,
    "timestamps": true,
    "clientEvents": [
        "scroll",
        "scroll:element",
        "input:text",
        "input:toggles",
        "form:submit",
        "form:reset",
        "click"
    ],
    "socket": {
        "socketIoOptions": {
            "log": false
        },
        "socketIoClientConfig": {
            "reconnectionAttempts": 50
        },
        "path": "/browser-sync/socket.io",
        "clientPath": "/browser-sync",
        "namespace": "/browser-sync",
        "clients": {
            "heartbeatTimeout": 5000
        }
    },
    "tagNames": {
        "less": "link",
        "scss": "link",
        "css": "link",
        "jpg": "img",
        "jpeg": "img",
        "png": "img",
        "svg": "img",
        "gif": "img",
        "js": "script"
    }
};
