'use strict';

const com = require('../../src/index')
com.doc.debug = true;

describe('module com', function() {

  describe('#module', function() {

    beforeEach(function() {
      com.doc.safeToWrite(null);
    });

    it('should expose api', function() {
      expect(com).to.have.ownProperty('doc');
      expect(com.doc).to.have.ownProperty('write');
      expect(com.doc).to.have.ownProperty('script');
      expect(com.doc).to.have.ownProperty('safeToWrite');
    });

    it('can write content directly to `document`', function() {
      let documentOutput, timestamp = `TS:${(new Date()).getTime()}`;
      global.document.write.callback = function() {
        const args = Array.prototype.slice.call(arguments);
        documentOutput = args.join('');
      };

      expect(documentOutput).to.be.an('undefined');
      com.doc.safeToWrite(/[a-z0-9]/g);
      com.doc.write(timestamp);
      expect(documentOutput).not.to.be.an('undefined');
      expect(documentOutput).to.equal(timestamp);
    });

    it('can load script directly to `document`', function() {
      let documentOutput;
      const timestamp = `TS:${(new Date()).getTime()}`;
      const filePath = `/file/url/${timestamp}.js`;

      global.document.write.callback = function() {
        const args = Array.prototype.slice.call(arguments);
        documentOutput = args.join('');
      };

      expect(documentOutput).to.be.an('undefined');
      com.doc.safeToWrite('/file/url');
      com.doc.script(filePath);
      expect(documentOutput).not.to.be.an('undefined');
      expect(documentOutput).to.match(/^\<script src=\"*(.+)"*(.+)script\>/);
      expect(documentOutput).to.have.string(filePath);
    });

  });

});
